import { LogLevel } from '@genesislcap/foundation-logger';
/**
 * @public
 * enum for different types of error boundary events
 */
export declare enum ErrorBoundaryEvent {
    ERROR_BOUNDARY_EVENT = "error-boundary-event"
}
/**
 * @public
 * type for error notification type
 */
export type ErrorNotificationType = 'warning' | 'success';
/**
 * @public
 * type for error notification position
 */
export type ErrorNotificationPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
/**
 * Interface for Error Notification configuration
 * @public
 */
export interface ErrorNotification {
    readonly position?: ErrorNotificationPosition;
    readonly type?: ErrorNotificationType;
    readonly autoClose?: boolean;
    readonly closeTimeout?: number;
}
/**
 * Interface for Dismissing Action configuration
 * @public
 */
export interface DismissingAction {
    readonly label: String;
    readonly action?: Function;
}
/**
 * Interface for Confirming Action configuration
 * @public
 */
export interface ConfirmingAction {
    readonly label: String;
    readonly action: Function;
}
/**
 * Interface for Error Dialog configuration
 * @public
 */
export interface ErrorDialog {
    readonly confirmingActions?: Array<ConfirmingAction>;
    readonly dismissingAction?: DismissingAction;
}
/**
 * Interface for Error Banner configuration
 * @public
 */
export interface ErrorBanner {
    readonly dismissingAction?: DismissingAction;
    readonly confirmingActions?: Array<ConfirmingAction>;
}
/**
 * @public
 * type for snackbar type
 */
export type SnackbarType = 'error';
/**
 * Interface for Error Snackbar configuration
 * @public
 */
export interface Snackbar {
    readonly type?: SnackbarType;
    readonly confirmingActions?: Array<ConfirmingAction>;
}
/**
 * Interface for Error Structure
 *  @public
 */
export interface ErrorStructure {
    readonly title: string;
    readonly errorDetails: string;
    readonly logLevel?: LogLevel;
    readonly config?: {
        /**
         * @deprecated Use logLevel from the top level instead
         */
        readonly logLevel?: LogLevel;
        readonly alert?: boolean;
        readonly notification?: ErrorNotification;
        readonly banner?: ErrorBanner;
        readonly snackbar?: Snackbar;
        readonly dialog?: ErrorDialog;
    };
}
/**
 * @internal
 */
export type ErrorElement = HTMLElement & {
    error: ErrorStructure;
};
/**
 * @internal
 */
export type ErrorDialogElement = ErrorElement & {
    show: Function;
};
//# sourceMappingURL=types.d.ts.map